<?php
	// Add support for custom headers.
	add_theme_support( 'custom-header', array(
	// The default header text color.
	'default-text-color'		=> '1b8be0',
	// The default header image.
	'default-image'				=> get_template_directory_uri() . '/images/header.jpg',
	// The height and width of our custom header.
	'width'						=> apply_filters( 'selaluceria_header_image_width', 1024 ),
	'height'					=> apply_filters( 'selaluceria_header_image_height', 200 ),
	// Callback for styling the header.
	'wp-head-callback'			=> 'selaluceria_header_style',
	// Callback for styling the header preview in the admin.
	'admin-head-callback'		=> 'selaluceria_admin_header_style',
	// Callback used to display the header preview in the admin.
	'admin-preview-callback'	=> 'selaluceria_admin_header_image'
	) );

// Styles the header image and text displayed on the blog
function selaluceria_header_style() {
	// Add Style Custom header
	$header_image = get_header_image();
	if ( $header_image ) : ?>
		<style type="text/css">
		#headerimage{
			border-bottom:1px solid #ccc;
			background-color: #fff;
			background-repeat: no-repeat;
			margin-top:2px
		}

		#headerimage:hover{
			background-position:bottom left
		}
		</style>		
	<?php endif;
	$text_color = get_header_textcolor();

	// If no custom options for text are set, let's bail.
	if ( $text_color == get_theme_support( 'custom-header', 'default-text-color' ) )
		return;
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $text_color ) :
	?>
		#blog-title,
		#blog-description {
			display: none
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		#blog-title a,
		#blog-description {
			color: #<?php echo $text_color; ?> !important;
		}
	<?php endif; ?>
	</style>
	<?php
}// End selaluceria_header_style()

// Styles the header image displayed on the Appearance > Header admin panel.
function selaluceria_admin_header_style() {
?>
<style type="text/css">
body.appearance_page_custom-header{
	min-width: 1408px
	}
body.appearance_page_custom-header #headimg{
	border: none;
	}
.selalu-ceria-clear{
	clear:both;
	display:block
	}

.selalu-ceria-clear:after{
	content:'';
	clear:both;
	display:block
	}
	
body.appearance_page_custom-header #headimg #selalu-ceria-top{
	min-height:40px;
	border-top:1px solid #fff;
	/* background:#c7c7c7; */
	background:#f0f1f3;
	border-bottom:7px solid #d7d7dd;
	background: -webkit-gradient(/* old webkit */linear,left top,left bottom,color-stop(0%, #d7d7dd),color-stop(98%, #f9f9f9),color-stop(98%, #f9f9f9));
	background: linear-gradient(top,#d7d7dd 0%,#f9f9f9 98%,#ffffff 98%);
	background: -moz-linear-gradient(top,#d7d7dd 0%,#f9f9f9 98%,#ffffff 98%);
	background: -webkit-linear-gradient(top,#d7d7dd 0%,#f9f9f9 98%,#ffffff 98%);
	background: -ms-linear-gradient(top,#d7d7dd 0%,#f9f9f9 98%,#ffffff 98%);
	background: -o-linear-gradient(top,#d7d7dd 0%,#f9f9f9 98%,#ffffff 98%);
	box-shadow:0 2px 0 #1b8be0;
	-moz-box-shadow:0 2px 0 #1b8be0;
	-webkit-box-shadow:0 2px 0 #1b8be0;
	-ms-box-shadow:0 2px 0 #1b8be0;
	-o-box-shadow:0 2px 0 #1b8be0
	}
	
body.appearance_page_custom-header #headimg #selalu-ceria-top .selalu-ceria-header{
	padding:12px 0 50px 0;
	text-shadow:0 1px 0 #fff;
	-moz-text-shadow:0 1px 0 #fff;
	-webkit-text-shadow:0 1px 0 #fff;
	-ms-text-shadow:0 1px 0 #fff;
	-o-text-shadow:0 1px 0 #fff
	}
	
body.appearance_page_custom-header #headimg #selalu-ceria-top .selalu-ceria-header .selalu-ceria-header-title{
	width:70%;
	float:left
	}

body.appearance_page_custom-header #headimg #selalu-ceria-top .selalu-ceria-header .selalu-ceria-header-title h1{
	margin:0;
	padding:0
	}
body.appearance_page_custom-header #headimg #selalu-ceria-top .selalu-ceria-header .selalu-ceria-header-title h1 a{
	font:normal bold 19px georgia, serif!important;
	text-decoration: none;
	}

body.appearance_page_custom-header #headimg #selalu-ceria-top .selalu-ceria-header .selalu-ceria-header-title div#desc{
	color:#3573a0;
	font:normal normal 16px georgia, serif!important;
	padding-left:2%;
	margin:0
	}
	
body.appearance_page_custom-header #headimg #headerimage{
	border-bottom:1px solid #ccc;
	background-color: #fff;
	background-repeat: no-repeat;
	margin-top:2px
	}
	
body.appearance_page_custom-header #headimg  #headerimage:hover{
	background-position:bottom left
	}
	<?php
		// If the user has set a custom color for the text use that
		if ( get_header_textcolor() != get_theme_support( 'custom-header', 'default-text-color' ) ) :
	?>

	#blog-title a,
	#blog-description {
		color: #<?php echo get_header_textcolor(); ?>;
		}
	<?php endif; ?>
	</style>
<?php
}// End selaluceria_admin_header_style()

// Custom header image markup displayed on the Appearance > Header admin panel.
function selaluceria_admin_header_image() { ?>
	<div id="headimg" class="selalu-ceria-clear">
		<?php
		$color = get_header_textcolor();
		$image = get_header_image();
		$image_height = get_custom_header()->height;
		$image_width = get_custom_header()->width;
		if ( $color && $color != 'blank' )
			$style = ' style="color:#' . $color . '"';
		else
			$style = ' style="display:none"';
		?>
		<div id='selalu-ceria-top' class='selalu-ceria-clear'>
			<div class='selalu-ceria-header selalu-ceria-width'>
				<div class='selalu-ceria-header-title'>
					<h1 id="blog-title"><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
					<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
				</div><!-- selalu-ceria-header-title -->
			</div><!-- End .selalu-ceria-header .selalu-ceria-width -->
		</div><!-- End #selalu-ceria-top .selalu-ceria-clear -->

		<?php
			if ( $image ) :
				echo "<div id='headerimage' style='background-image:url(" . esc_url( $image ) . ");width: " . $image_width . "px;height:" . $image_height . "px;'></div>";
			endif;
		 ?>
	</div><!-- End #headimg -->
<?php } // End selaluceria_admin_header_image()